summaryrefslogtreecommitdiffstats
path: root/sys/dev/usb/usb_dev.h
diff options
context:
space:
mode:
authorthompsa <thompsa@FreeBSD.org>2009-05-28 17:36:36 +0000
committerthompsa <thompsa@FreeBSD.org>2009-05-28 17:36:36 +0000
commitaf6fb4f3d2a2950c2a2c95bc3148ee16510149de (patch)
tree3036722a60a7a9ddd5122172e56736f3e128664b /sys/dev/usb/usb_dev.h
parentd691011026fb63bdede5854aaa7547c7c019cd38 (diff)
downloadFreeBSD-src-af6fb4f3d2a2950c2a2c95bc3148ee16510149de.zip
FreeBSD-src-af6fb4f3d2a2950c2a2c95bc3148ee16510149de.tar.gz
s/usb2_/usb_/ on all C structs for the USB stack.
Diffstat (limited to 'sys/dev/usb/usb_dev.h')
-rw-r--r--sys/dev/usb/usb_dev.h112
1 files changed, 56 insertions, 56 deletions
diff --git a/sys/dev/usb/usb_dev.h b/sys/dev/usb/usb_dev.h
index af252c5..da3966a 100644
--- a/sys/dev/usb/usb_dev.h
+++ b/sys/dev/usb/usb_dev.h
@@ -38,17 +38,17 @@
#define USB_FIFO_TX 0
#define USB_FIFO_RX 1
-struct usb2_fifo;
-struct usb2_mbuf;
+struct usb_fifo;
+struct usb_mbuf;
-typedef int (usb2_fifo_open_t)(struct usb2_fifo *fifo, int fflags);
-typedef void (usb2_fifo_close_t)(struct usb2_fifo *fifo, int fflags);
-typedef int (usb2_fifo_ioctl_t)(struct usb2_fifo *fifo, u_long cmd, void *addr, int fflags);
-typedef void (usb2_fifo_cmd_t)(struct usb2_fifo *fifo);
-typedef void (usb2_fifo_filter_t)(struct usb2_fifo *fifo, struct usb2_mbuf *m);
+typedef int (usb2_fifo_open_t)(struct usb_fifo *fifo, int fflags);
+typedef void (usb2_fifo_close_t)(struct usb_fifo *fifo, int fflags);
+typedef int (usb2_fifo_ioctl_t)(struct usb_fifo *fifo, u_long cmd, void *addr, int fflags);
+typedef void (usb2_fifo_cmd_t)(struct usb_fifo *fifo);
+typedef void (usb2_fifo_filter_t)(struct usb_fifo *fifo, struct usb_mbuf *m);
-struct usb2_symlink {
- TAILQ_ENTRY(usb2_symlink) sym_entry;
+struct usb_symlink {
+ TAILQ_ENTRY(usb_symlink) sym_entry;
char src_path[32]; /* Source path - including terminating
* zero */
char dst_path[32]; /* Destination path - including
@@ -62,7 +62,7 @@ struct usb2_symlink {
* "usb2_fifo_cmd_t" and "usb2_fifo_filter_t" functions are called
* locked. The others are called unlocked.
*/
-struct usb2_fifo_methods {
+struct usb_fifo_methods {
usb2_fifo_open_t *f_open;
usb2_fifo_close_t *f_close;
usb2_fifo_ioctl_t *f_ioctl;
@@ -84,12 +84,12 @@ struct usb2_fifo_methods {
/*
* Private per-device information.
*/
-struct usb2_cdev_privdata {
- struct usb2_bus *bus;
- struct usb2_device *udev;
- struct usb2_interface *iface;
- struct usb2_fifo *rxfifo;
- struct usb2_fifo *txfifo;
+struct usb_cdev_privdata {
+ struct usb_bus *bus;
+ struct usb_device *udev;
+ struct usb_interface *iface;
+ struct usb_fifo *rxfifo;
+ struct usb_fifo *txfifo;
int bus_index; /* bus index */
int dev_index; /* device index */
int ep_addr; /* endpoint address */
@@ -101,7 +101,7 @@ struct usb2_cdev_privdata {
uint8_t is_usbfs; /* USB-FS is active */
};
-struct usb2_fs_privdata {
+struct usb_fs_privdata {
int bus_index;
int dev_index;
int ep_addr;
@@ -109,29 +109,29 @@ struct usb2_fs_privdata {
int fifo_index;
struct cdev *cdev;
- LIST_ENTRY(usb2_fs_privdata) pd_next;
+ LIST_ENTRY(usb_fs_privdata) pd_next;
};
/*
* Most of the fields in the "usb2_fifo" structure are used by the
* generic USB access layer.
*/
-struct usb2_fifo {
- struct usb2_ifqueue free_q;
- struct usb2_ifqueue used_q;
+struct usb_fifo {
+ struct usb_ifqueue free_q;
+ struct usb_ifqueue used_q;
struct selinfo selinfo;
struct cv cv_io;
struct cv cv_drain;
- struct usb2_fifo_methods *methods;
- struct usb2_symlink *symlink[2];/* our symlinks */
+ struct usb_fifo_methods *methods;
+ struct usb_symlink *symlink[2];/* our symlinks */
struct proc *async_p; /* process that wants SIGIO */
- struct usb2_fs_endpoint *fs_ep_ptr;
- struct usb2_device *udev;
- struct usb2_xfer *xfer[2];
- struct usb2_xfer **fs_xfer;
+ struct usb_fs_endpoint *fs_ep_ptr;
+ struct usb_device *udev;
+ struct usb_xfer *xfer[2];
+ struct usb_xfer **fs_xfer;
struct mtx *priv_mtx; /* client data */
/* set if FIFO is opened by a FILE: */
- struct usb2_cdev_privdata *curr_cpd;
+ struct usb_cdev_privdata *curr_cpd;
void *priv_sc0; /* client data */
void *priv_sc1; /* client data */
void *queue_data;
@@ -149,53 +149,53 @@ struct usb2_fifo {
uint8_t flag_stall; /* set if clear stall should be run */
uint8_t iface_index; /* set to the interface we belong to */
uint8_t fifo_index; /* set to the FIFO index in "struct
- * usb2_device" */
+ * usb_device" */
uint8_t fs_ep_max;
uint8_t fifo_zlp; /* zero length packet count */
uint8_t refcount;
#define USB_FIFO_REF_MAX 0xFF
};
-struct usb2_fifo_sc {
- struct usb2_fifo *fp[2];
+struct usb_fifo_sc {
+ struct usb_fifo *fp[2];
struct cdev* dev;
};
extern struct cdevsw usb2_devsw;
-int usb2_fifo_wait(struct usb2_fifo *fifo);
-void usb2_fifo_signal(struct usb2_fifo *fifo);
-int usb2_fifo_alloc_buffer(struct usb2_fifo *f, uint32_t bufsize,
+int usb2_fifo_wait(struct usb_fifo *fifo);
+void usb2_fifo_signal(struct usb_fifo *fifo);
+int usb2_fifo_alloc_buffer(struct usb_fifo *f, uint32_t bufsize,
uint16_t nbuf);
-void usb2_fifo_free_buffer(struct usb2_fifo *f);
-int usb2_fifo_attach(struct usb2_device *udev, void *priv_sc,
- struct mtx *priv_mtx, struct usb2_fifo_methods *pm,
- struct usb2_fifo_sc *f_sc, uint16_t unit, uint16_t subunit,
+void usb2_fifo_free_buffer(struct usb_fifo *f);
+int usb2_fifo_attach(struct usb_device *udev, void *priv_sc,
+ struct mtx *priv_mtx, struct usb_fifo_methods *pm,
+ struct usb_fifo_sc *f_sc, uint16_t unit, uint16_t subunit,
uint8_t iface_index, uid_t uid, gid_t gid, int mode);
-void usb2_fifo_detach(struct usb2_fifo_sc *f_sc);
-uint32_t usb2_fifo_put_bytes_max(struct usb2_fifo *fifo);
-void usb2_fifo_put_data(struct usb2_fifo *fifo, struct usb2_page_cache *pc,
+void usb2_fifo_detach(struct usb_fifo_sc *f_sc);
+uint32_t usb2_fifo_put_bytes_max(struct usb_fifo *fifo);
+void usb2_fifo_put_data(struct usb_fifo *fifo, struct usb_page_cache *pc,
usb2_frlength_t offset, usb2_frlength_t len, uint8_t what);
-void usb2_fifo_put_data_linear(struct usb2_fifo *fifo, void *ptr,
+void usb2_fifo_put_data_linear(struct usb_fifo *fifo, void *ptr,
usb2_size_t len, uint8_t what);
-uint8_t usb2_fifo_put_data_buffer(struct usb2_fifo *f, void *ptr, usb2_size_t len);
-void usb2_fifo_put_data_error(struct usb2_fifo *fifo);
-uint8_t usb2_fifo_get_data(struct usb2_fifo *fifo, struct usb2_page_cache *pc,
+uint8_t usb2_fifo_put_data_buffer(struct usb_fifo *f, void *ptr, usb2_size_t len);
+void usb2_fifo_put_data_error(struct usb_fifo *fifo);
+uint8_t usb2_fifo_get_data(struct usb_fifo *fifo, struct usb_page_cache *pc,
usb2_frlength_t offset, usb2_frlength_t len, usb2_frlength_t *actlen,
uint8_t what);
-uint8_t usb2_fifo_get_data_linear(struct usb2_fifo *fifo, void *ptr,
+uint8_t usb2_fifo_get_data_linear(struct usb_fifo *fifo, void *ptr,
usb2_size_t len, usb2_size_t *actlen, uint8_t what);
-uint8_t usb2_fifo_get_data_buffer(struct usb2_fifo *f, void **pptr,
+uint8_t usb2_fifo_get_data_buffer(struct usb_fifo *f, void **pptr,
usb2_size_t *plen);
-void usb2_fifo_get_data_error(struct usb2_fifo *fifo);
-uint8_t usb2_fifo_opened(struct usb2_fifo *fifo);
-void usb2_fifo_free(struct usb2_fifo *f);
-void usb2_fifo_reset(struct usb2_fifo *f);
-void usb2_fifo_wakeup(struct usb2_fifo *f);
-struct usb2_symlink *usb2_alloc_symlink(const char *target);
-void usb2_free_symlink(struct usb2_symlink *ps);
+void usb2_fifo_get_data_error(struct usb_fifo *fifo);
+uint8_t usb2_fifo_opened(struct usb_fifo *fifo);
+void usb2_fifo_free(struct usb_fifo *f);
+void usb2_fifo_reset(struct usb_fifo *f);
+void usb2_fifo_wakeup(struct usb_fifo *f);
+struct usb_symlink *usb2_alloc_symlink(const char *target);
+void usb2_free_symlink(struct usb_symlink *ps);
int usb2_read_symlink(uint8_t *user_ptr, uint32_t startentry,
uint32_t user_len);
-void usb2_fifo_set_close_zlp(struct usb2_fifo *, uint8_t);
+void usb2_fifo_set_close_zlp(struct usb_fifo *, uint8_t);
#endif /* _USB2_DEV_H_ */
OpenPOWER on IntegriCloud
@@ -109,29 +109,29 @@ struct usb2_fs_privdata {
};
/*
- * Most of the fields in the "usb2_fifo" structure are used by the
+ * Most of the fields in the "usb_fifo" structure are used by the
* generic USB access layer.
*/